@@ -35,7 +35,9 @@ struct sis1100_global {
 #endif
 } sis1100_global;
 
-#if LINUX_VERSION_CODE > KERNEL_VERSION(2,6,18)
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(3,8,0)
+struct pci_device_id sis1100_table[] ={
+#elif LINUX_VERSION_CODE > KERNEL_VERSION(2,6,18)
 struct pci_device_id sis1100_table[] __devinitconst={
 #else
 struct pci_device_id sis1100_table[] __devinit={
@@ -178,7 +180,11 @@ const char *subnames[4]={"remote", "ram", "ctrl", "dsp"};
 /*
  * sis1100_linux_init is called whenever a sis1100 PCI card is found
  */
-static int __devinit
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(3,8,0)
+ static int
+#else
+ static int __devinit
+#endif
 init_sis1100_device(struct pci_dev *pdev, const struct pci_device_id *ent)
 {
         struct sis1100_softc *sc;
@@ -437,7 +443,11 @@ error:
  * during unload
  * (unload is forced e.g. by shutdown)
  */
-static void __devexit
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(3,8,0)
+ static void
+#else
+ static void __devexit
+#endif
 done_sis1100_device(struct pci_dev *pdev)
 {
 	struct sis1100_softc *sc;
